"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.vueHandler = void 0;
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const promises_1 = require("fs/promises");
const glob_1 = __importDefault(require("glob"));
const ts_morph_1 = require("ts-morph");
const extractTypeScriptFromVue_1 = require("../lib/extractTypeScriptFromVue");
const progressBar_1 = require("../lib/progressBar");
const suppressTsErrors_1 = require("../lib/suppressTsErrors");
const vueHandler = async ({ tsconfigPath, commentType, errorCode, targetPathPattern, }) => {
    // Extract script from vue files
    const filePaths = glob_1.default.sync(targetPathPattern);
    const allFiles = await Promise.all(filePaths.map(async (path) => {
        const fullText = await (0, promises_1.readFile)(path, "utf8");
        const script = (0, extractTypeScriptFromVue_1.extractTypeScriptFromVue)(fullText);
        return {
            path,
            fullText,
            script,
        };
    }));
    // Filter only files with script
    const targetFiles = allFiles.filter((file) => file.script !== "");
    // Start progress bar
    const progressBar = (0, progressBar_1.generateProgressBar)(ansi_colors_1.default.green);
    progressBar.start(targetFiles.length, 0);
    // Add source to project
    const project = new ts_morph_1.Project({ tsConfigFilePath: tsconfigPath });
    const targetFilesWithSourceFile = targetFiles.map((file) => {
        const sourceFile = project.createSourceFile(`${file.path}.ts`, file.script);
        return {
            ...file,
            sourceFile,
        };
    });
    // Rewrite script in vue file with script with comment
    // NOTE: Running in series because the progress bar count does not work well in parallel
    let insertedCommentCount = 0;
    for await (const file of targetFilesWithSourceFile) {
        const { text: scriptWithComment, count } = (0, suppressTsErrors_1.suppressTsErrors)({
            sourceFile: file.sourceFile,
            commentType,
            withErrorCode: errorCode,
        });
        const newText = file.fullText.replace(file.script, scriptWithComment);
        await (0, promises_1.writeFile)(file.path, newText);
        insertedCommentCount += count;
        progressBar.increment();
    }
    progressBar.stop();
    return insertedCommentCount;
};
exports.vueHandler = vueHandler;
