"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ts_morph_1 = require("ts-morph");
const vitest_1 = require("vitest");
const buildComment_1 = require("../buildComment");
(0, vitest_1.describe)("buildComment", () => {
    let project;
    (0, vitest_1.beforeAll)(() => {
        project = new ts_morph_1.Project({ compilerOptions: { strict: true } });
    });
    const baseParam = {
        source: `
        const a: string = 1;
      `,
        fileName: "test.ts",
        lineNumber: 2,
        commentType: 1,
        errorCode: 2322,
        withErrorCode: true,
    };
    vitest_1.it.each([
        {
            ...baseParam,
            expected: "        // @ts-expect-error TS2322",
        },
        {
            ...baseParam,
            commentType: 2,
            expected: "        // @ts-ignore TS2322",
        },
        {
            ...baseParam,
            commentType: 2,
            withErrorCode: false,
            expected: "        // @ts-ignore",
        },
        {
            ...baseParam,
            source: `
      function func(num: number) {
        if(foo) {
          return num.map(n => n)
        }
      }
      `,
            lineNumber: 4,
            expected: "          // @ts-expect-error TS2322",
        },
        {
            ...baseParam,
            fileName: "target.tsx",
            source: `
      function tsxFunc(num: number) {
        return <div>{num.map(n => n)}</div>
      }
      `,
            lineNumber: 3,
            expected: "        // @ts-expect-error TS2322",
        },
        {
            ...baseParam,
            fileName: "target.tsx",
            source: `
      function tsxFunc(num: number) {
        return (
          <div>{num.map(n => n)}</div>
        )
      }
      `,
            lineNumber: 4,
            expected: "          {/*\n           // @ts-expect-error TS2322 */}",
        },
        {
            ...baseParam,
            fileName: "target.tsx",
            source: `
      function tsxFunc(classList: string[]) {
        return (
          <div
            className="classList"
          >foo</div>
        )
      }
      `,
            lineNumber: 5,
            expected: "            // @ts-expect-error TS2322",
        },
    ])("build comment", ({ source, fileName, lineNumber, commentType, errorCode, withErrorCode, expected, }) => {
        const sourceFile = project.createSourceFile(fileName, source, {
            overwrite: true,
        });
        const result = (0, buildComment_1.buildComment)({
            sourceFile,
            lineNumber,
            commentType,
            errorCode,
            withErrorCode,
        });
        (0, vitest_1.expect)(result).toBe(expected);
    });
});
