"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildComment = void 0;
const ts_morph_1 = require("ts-morph");
const constants_1 = require("./constants");
const getWhiteSpaceCountFromLineNumber = (sourceFile, lineNumber) => {
    const targetLineString = sourceFile.getFullText().split("\n")[lineNumber - 1];
    return targetLineString.search(/\S/);
};
function isSomKindOfJsxAtLine(sourceFile, lineNumber) {
    const targetNode = sourceFile.getDescendants().find((node) => {
        return lineNumber === node.getStartLineNumber();
    });
    if (!targetNode) {
        throw new Error(`targetNode is not found at line ${lineNumber}`);
    }
    return [
        ts_morph_1.ts.SyntaxKind.JsxText,
        ts_morph_1.ts.SyntaxKind.JsxTextAllWhiteSpaces,
        ts_morph_1.ts.SyntaxKind.JsxElement,
        ts_morph_1.ts.SyntaxKind.JsxSelfClosingElement,
        ts_morph_1.ts.SyntaxKind.JsxClosingElement,
        ts_morph_1.ts.SyntaxKind.JsxFragment,
        ts_morph_1.ts.SyntaxKind.JsxOpeningFragment,
        ts_morph_1.ts.SyntaxKind.JsxClosingFragment,
        ts_morph_1.ts.SyntaxKind.JsxExpression,
        ts_morph_1.ts.SyntaxKind.JsxOpeningElement,
        // NOTE: Errors in element tags are not jsx comments, so exclude them
        // ts.SyntaxKind.JsxAttribute,
        // ts.SyntaxKind.JsxAttributes,
        // ts.SyntaxKind.JsxSpreadAttribute,
    ].includes(targetNode.getKind());
}
const buildComment = ({ sourceFile, lineNumber, commentType, errorCode, withErrorCode, }) => {
    const comment = commentType === 1 ? constants_1.COMMENT_TYPE.EXPECT_ERROR : constants_1.COMMENT_TYPE.IGNORE;
    const whiteSpaceCount = getWhiteSpaceCountFromLineNumber(sourceFile, lineNumber);
    sourceFile;
    return isSomKindOfJsxAtLine(sourceFile, lineNumber)
        ? `${" ".repeat(whiteSpaceCount)}{/*\n${" ".repeat(whiteSpaceCount + 1)}// ${comment}${withErrorCode ? ` TS${errorCode}` : ""} */}`
        : `${" ".repeat(whiteSpaceCount)}// ${comment}${withErrorCode ? ` TS${errorCode}` : ""}`;
};
exports.buildComment = buildComment;
